
#ifndef _C14_ds678_
#define _C14_ds678_

#ifdef __cplusplus
extern "C" {
#endif

extern void F895_5949(EIF_REFERENCE);
extern void EIF_Minit678(void);
extern void F942_6438(EIF_REFERENCE, EIF_REFERENCE);

#ifdef __cplusplus
}
#endif

#endif
